/**********************************************************************************
 Persistence of Vision Ray Tracer Scene Description File
 File name   : Glass_test.pov
 Version     : 3.8
 Description : How to do glass material in version 3.8
               
 Date        : August 2022
 Author      : Alain Martel for the glass; scene by Thomas de Groot
               https://news.povray.org/povray.general/thread/%3Cweb.62e942de1adc8eb48a3c0aee5cc1b6e%40news.povray.org%3E/               
 
**********************************************************************************/

// Render settings 3.7+ (right-click on a line below):
// +w640 +h640 +a0.3 +am2 +bm2 +bs8 +wt7
// or, for a stochastic render:
// +w640 +h640 +am3 +a0.01 +ac0.90 +r3 +bm2 +bs8 +wt7

#version 3.8;

// ==== Standard POV-Ray Includes ====
#include "colors.inc"	  // Standard Color definitions
#include "textures.inc"	  // Standard Texture definitions
#include "functions.inc"  // internal functions usable in user defined functions

#declare Stochastic = off;
#declare Photons    = on;
#declare SavePhot   = off;

/*===============================================================================================================
Alain Martel:
------------
Normally, for a transparent object having an IOR, you use reflection{1 fresnel} to control the reflectivity. 
There is usually no need to use another value here.
Fresnel reflection depends entirely on the ratio between the ior on each sides of the surface and the angle of incidence. 
A ratio of 1 mean NO reflection. A standalone object without an interior defining an ior different from 1 will also show no fresnel reflection.

When the fresnel keyword is present, it always default to ON.
falloff and exponent should be left to their default values. Don't use those.
Do not use metallic.

Then, you should also use the fresnel option for the highlights. Need the latest version. 
IIRC, it was not implemented in version 3.7, but is supported in the latest V1.8 beta.
Examples : specular 0.7 fresnel roughness 0.001, phong 0.7 fresnel phong_size 500

Also, you should use transmit 1 or filter 1 as your pigment.
If you want the object to be coloured, use fading in the interior statement :
interior{ior 1.5 fade_color rgb<1, 0.6, 0.6> fade_distance 1 fade_power 1001}// A pink object.
Adjust fade_distance for the dimension and scale of your object. It's easily the most important parameter when using fading colours in an interior.

ALWAYS use conserve_energy.

Sample glass:
texture{
    pigment{rgbt 1}
    finish{specular 1 roughness 0.001 fresnel
        ambient 0 diffuse 0
        reflection{ 1 fresnel }
        conserve_energy
    }
}
interior{ ior 1.5 //typical glass IOR
    fade_color rgb<0.9, 1, 0.9>//slightly greenish
    fade_distance 2 // Adjust to the size and scale of the object
    fade_power 1001
} 

----------------------------------------------------------------------------------
You use albedo when you also use a brilliance that differs from the default of 1.
As I did not use brilliance in my example, it was not useful to use albedo.

Example of the use of albedo and fresnel with an opaque pigment:
pigment {rgb <0.7, 1, 0.2>}
finish {
  brilliance 10                      // high brilliance for a very highly polished surface
  diffuse albedo 0.7                 // albedo needed to have correct illumination
  specular albedo 1 roughness 0.01   // albedo also needed due to the high brilliance
                                     // I like to put the roughness on the same line as specular as they work together
                                     // Same thing for phong and phong_size.
  fresnel                            // have the IOR also affect the highlights
  reflection {1 fresnel}
}
interior {ior 1.7} 

===============================================================================================================*/

global_settings {
  assumed_gamma 1.0
    radiosity {
      pretrace_start 16/max(image_width,image_height)   //Ive
      pretrace_end   4/max(image_width,image_height)    //Ive
      minimum_reuse  4/(max(image_width,image_height)-0.05) //Ive? Alain Martel
      // And for really high quality and/or radiosity only scenes:
      // pretrace_start  8/max(image_width,image_height)
      // pretrace_end    1/max(image_width,image_height) 

      #if (Stochastic)
        count          10
      #else
        count          100, 1000  // higher -> higher quality (1..1600) [35]
      #end
      nearest_count    10, 5     // higher -> higher quality (1..10) [5]
      error_bound      1         // higher -> smoother, less accurate [1.8]
      recursion_limit  2         // how much interreflections are calculated (1..5+) [3]
      low_error_factor 0.3       // reduce error_bound during last pretrace step
      gray_threshold   0.0       // increase for weakening colors (0..1) [0]
      maximum_reuse    0.1		   // new parameter 3.7 [0.2]
      brightness       1         // brightness of radiosity effects (0..1) [1]

      adc_bailout      0.01/2
      normal           on     // take surface normals into account [off]
      media            off     // take media into account [off]
      always_sample    off     // turn sampling in final trace off [on]
      //max_sample     1.0     // maximum brightness of samples
    }
  #if (Photons)
  photons {
    spacing 0.001                 // specify the density of photons
    //count 100000              // alternatively use a total number of photons
    autostop 0
    jitter .4
    media 100
    #if (SavePhot)
      save_file "Glass.ph"
    #else
      load_file "Glass.ph"
    #end
  }
  #end
}

// ----------------------------------------

camera {
  location  <0.0, 0.5, -4.5>
  direction 1.5*z
  right     x*image_width/image_height
  angle     50
  look_at   <0.0, 0.0,  0.0>
}

light_source {
  <0, 0, 0>
  color rgb <1, 1, 1>*2
  translate <-30, 70, 30>
  #if (Photons)
  photons {
    refraction on
    reflection on
  }
  #end
}

sphere {
	0, 200
	pigment {
		image_map {
			hdr "Office_1_LL.hdr" map_type 1
			interpolate 2
		}
	}
	finish {emission 30 diffuse 0}
	inverse	
  #if (Photons)
  photons {
    refraction on
    reflection on
  }
  #end
}

//table:
intersection {
  plane {y, -1}
  box {<-5, -2, -5>, <5, 1, 5> rotate 30*y}
  pigment {
    bozo 
    warp {turbulence 0.5}
    pigment_map {
      [0.4 rgb <0.7, 0.5, 0.3>]
      [0.6 rgb <0.6, 0.4, 0.2>]
    }
    warp {turbulence 0.5}
    scale 0.25
  }
  finish {
    diffuse 0.6
    specular 0.2
    roughness 0.001
  }
  normal {
    bozo 1.0
    warp {turbulence 0.5}
    normal_map {
      [0.4 granite 1.5 scale 0.1]
      [0.6 granite 0.9 scale 0.2]
    }
    warp {turbulence 0.5}
    scale 0.25
  }
  #if (Photons)
  photons {
    refraction off
    reflection off
  }
  #end
}

//-------------------------------------------------------------------------
sphere {0.0, 1
  hollow
  texture{
    pigment {rgbt 1}
    finish {
      specular 1 roughness 0.001 fresnel
      ambient 0 
      diffuse 0
      reflection { 1 fresnel }
      conserve_energy
    }
  }
  interior { 
    ior 1.5 //typical glass IOR
    
    fade_color rgb <0.5, 1, 0.5>  //greenish
    fade_distance 0.1 // Adjust to the size and scale of the object
    fade_power 1001 
  }
  translate <0.0, 0.01, 4.5>
  rotate -10*y
  #if (Photons)
    photons {  // photon block for an object
      target 1.0
      refraction on
      reflection on
    }
  #end
}

//-------------------------------------------------------------------------
box { -1, 1
  hollow
  texture{
    pigment {rgbt 1}
    finish {
      specular 1 roughness 0.001 fresnel
      ambient 0 
      diffuse 0
      reflection { 1 fresnel }
      conserve_energy
    }
  }
  interior { 
    ior 1.5 //typical glass IOR
    
    fade_color rgb <1, 1, 0.8>  //yellowish
    fade_distance 0.01 // Adjust to the size and scale of the object
    fade_power 1001 
  }
  #if (Photons)
    photons {  // photon block for an object
      target 1.0
      refraction on
      reflection on
    }
  #end
  scale <1, 1, 0.1>
  rotate -20.5*y
  translate 0.01*y
}

//-------------------------------------------------------------------------
//using albedo when brilliance different from default 1:
difference {
  cylinder {<0.0, -1.0, 0.0>, <0.0, 0.0, 0.0>, 0.25}
  sphere {< 0.00, -0.50,  0.00>, 0.02}
  sphere {< 0.05, -0.40,  0.00>, 0.02}
  sphere {<-0.05, -0.10,  0.10>, 0.02}
  sphere {< 0.10, -0.80, -0.05>, 0.02}
  sphere {<-0.05, -0.65, -0.10>, 0.02}
  sphere {< 0.10, -0.25,  0.05>, 0.02}
  hollow
  texture{
    pigment {rgbt 1}
    finish {
      brilliance 10                             // high brilliance for a very highly polished surface
      diffuse albedo 0.7                        // albedo needed to have correct illumination
      specular albedo 1 roughness 0.001 fresnel // albedo also needed due to the high brilliance 
      ambient 0 
      reflection { 1 fresnel }
      conserve_energy
    }
  }
  interior { 
    ior 1.5 //typical glass IOR
    
    fade_color rgb <0.8, 1.0, 1.0>  //bluish
    fade_distance 0.01 // Adjust to the size and scale of the object
    fade_power 1001 
  }
  #if (Photons)
    photons {  // photon block for an object
      target 1.0
      refraction on
      reflection on
    }
  #end
  translate <-1.2, 0.01, -1.0>
}

//-------------------------------------------------------------------------
ovus { 1.00, 0.65 
  hollow
  texture{
    pigment {rgbt 1}
    finish {
      specular 1 roughness 0.001 fresnel
      ambient 0 
      diffuse 0
      reflection {1 fresnel }
      conserve_energy
    }
  }
  interior { 
    ior 1.5 //typical glass IOR
    
    fade_color rgb <0.9, 0.9, 0.9>  //whitish
    fade_distance 0.25 // Adjust to the size and scale of the object
    fade_power 1001 

    media {   //a media filling the object
      intervals 1
      samples 50
      scattering {1, <0.5, 0.8, 1.0>*0.5}
      density {
        bozo
        color_map {
          [0.40 rgb 0.0]
          [0.40 rgb <1, 0, 1>]
          [0.60 rgb <1, 0, 1>]
          [0.60 rgb 0.0]
        }
        scale 0.25
      }
    }
  }
  #if (Photons)
    photons {  // photon block for an object
      target 1.0
      refraction on
      reflection on
    }
  #end
  scale 0.5
  translate -0.5*y
  translate <1.75, 0.01, 0.75> 
} 

//-------------------------------------------------------------------------
#include "Glass_bunny_POV_geom.inc"

#declare Glass_bunny =
object {bunny_
  hollow
  texture{
    pigment {rgbt 1}
    finish {
      specular 1 roughness 0.001 fresnel
      ambient 0 
      diffuse 0
      reflection { 1 fresnel }
      conserve_energy
    }
  }
  interior { 
    ior 1.5 //typical glass IOR
    
    fade_color rgb <0.95, 0.85, 0.85>  //brownish
    fade_distance 0.05 // Adjust to the size and scale of the object
    fade_power 1001 
  }
  #if (Photons)
    photons {  // photon block for an object
      target 1.0
      refraction on
      reflection on
    }
  #end
  scale 0.70*10
  rotate -200*y
  translate <0.70, -0.99, -1.20>
}

Glass_bunny

//-------------------------------------------------------------------------
